import 'package:feed_plugin_example/localization/gettext/gettext.dart';
import 'package:feed_plugin_example/localization/gettext/parser.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart' show rootBundle;


class PhonedoLocalizations {
  final Gettext gt;

  PhonedoLocalizations(this.gt);

  static PhonedoLocalizations? of(BuildContext context) {
    return Localizations.of<PhonedoLocalizations>(
        context, PhonedoLocalizations);
  }

  String get locale => gt.locale;

  bool get isSupportedLocale =>
      ['en', 'ru', 'he', 'ar', 'hu', 'el', 'es', 'fr','de','pt','nl'].contains(gt.locale);

  String translate(String value,
      {String domain = 'messages', Map<String, String>? msgctxt}) {
    var res = gt.gettext(value, domain: domain);
    if (msgctxt != null) {
      msgctxt.forEach((k, v) {
        res = res.replaceFirst(['{', k, '}'].join(), v);
      });
    }
    return res.replaceAll(r'\\', r'\');
  }
}

class PhonedoLocalizationsDelegate
    extends LocalizationsDelegate<PhonedoLocalizations> {
  @override
  bool isSupported(Locale locale) => [
        'en',
        'ru',
        'he',
        'ar',
        'hu',
        'el',
        'es',
        'fr',
        'de',
        'pt',
        'nl'
      ].contains(locale.languageCode);

  @override
  Future<PhonedoLocalizations> load(Locale locale) async {
    var data = await rootBundle
        .loadString('images/en.po');
    Map translateTable = PoParser(data).parse();
    final gt = Gettext();
    gt.locale = locale.languageCode;
    gt.addLocale(translateTable as Map<String, dynamic>);
    return PhonedoLocalizations(gt);
  }

  @override
  bool shouldReload(PhonedoLocalizationsDelegate old) => false;
}